==> ldapsaisie_1.8-6.tar.gz: ldapsaisie_clean3/public_html/tmp/f42923f474b713ac9da912d26a6790568d7df7dd_0.ls.top.tpl.php <==
<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2018-10-01 12:53:39
  from "ls:top.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5bb218d33c8a43_52151330',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'f42923f474b713ac9da912d26a6790568d7df7dd' => 
    array (
      0 => 'ls:top.tpl',
      1 => 1535729413,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
    'ls:LSdefault.tpl' => 1,
  ),
),false)) {
function content_5bb218d33c8a43_52151330 (Smarty_Internal_Template $_smarty_tpl) {
if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=<?php echo $_smarty_tpl->tpl_vars['LSencoding']->value;?>
">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value != '') {?> - <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['pagetitle']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base.css'),$_smarty_tpl);?>
" title="Normal" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base_print.css'),$_smarty_tpl);?>
" media='print' title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

  </head>
<body>

<?php $_smarty_tpl->_subTemplateRender('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>


<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <a href='index.php'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='logo'/></a>
      
      <?php if ($_smarty_tpl->tpl_vars['LSsession_subDn']->value != '') {?>
        <form action="index.php" method='post' id='LSsession_topDn_form'>
          <label><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['label_level']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

            <a href="index.php?LSsession_refresh"><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>
      <ul class='menu'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaccess']->value, 'label', false, 'LSobject_type');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['LSobject_type']->value => $_smarty_tpl->tpl_vars['label']->value) {
?>
        <li class='menu'><a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSobject_type']->value);?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
</a></li>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaddonsViewsAccess']->value, 'access');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['access']->value) {
?>
        <?php if ($_smarty_tpl->tpl_vars['access']->value['showInMenu']) {?>
        <li class='menu'><a href='addon_view.php?LSaddon=<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['LSaddon']);?>
&view=<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['id']);?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['access']->value['label']),$_smarty_tpl);?>
</a></li>
        <?php }?>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      </ul>
    </td>
    <td id='status'>
    <span><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang_label']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
        <option value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</option>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['connected_as']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 <span id='user_name'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_username']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</span><?php }?>
    <a href='index.php?LSsession_refresh=1'><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
" title="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
" /></a>
    <?php if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
' alt='Logout' title='Logout' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>
    
    

    
<?php }
}

==> ldapsaisie_2.1-0.tar.gz: ldapsaisie_clean3/public_html/tmp/f42923f474b713ac9da912d26a6790568d7df7dd_0.ls.top.tpl.php <==
<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:51:35
  from "ls:top.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5cf79eb7e036f4_11936531',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'f42923f474b713ac9da912d26a6790568d7df7dd' => 
    array (
      0 => 'ls:top.tpl',
      1 => 1559731651,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
    'ls:LSdefault.tpl' => 1,
  ),
),false)) {
function content_5cf79eb7e036f4_11936531 (Smarty_Internal_Template $_smarty_tpl) {
if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=<?php echo $_smarty_tpl->tpl_vars['LSencoding']->value;?>
">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value != '') {?> - <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['pagetitle']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base.css'),$_smarty_tpl);?>
" title="Normal" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base_print.css'),$_smarty_tpl);?>
" media='print' title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

  </head>
<body>

<?php $_smarty_tpl->_subTemplateRender('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>


<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <a href='index.php'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='logo'/></a>
      
      <?php if ($_smarty_tpl->tpl_vars['LSsession_subDn']->value != '') {?>
        <form action="index.php" method='post' id='LSsession_topDn_form'>
          <label><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['label_level']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

            <a href="index.php?LSsession_refresh"><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['_refresh']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>

      <?php if ($_smarty_tpl->tpl_vars['globalSearch']->value && $_smarty_tpl->tpl_vars['LSaccess']->value) {?>
      <form action='global_search.php' method='post' class='LSview_search LSglobal_search'>
        <input type='hidden' name='LSsearch_submit' value='1'/>
        <input type='text' name='pattern' class='LSview_search LSglobal_search' placeholder='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
'/>
        <input type='image' src='<?php echo LStemplate_smarty_img(array('name'=>'find'),$_smarty_tpl);?>
' alt='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
' title='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
' />
      </form>
      <?php }?>

      <ul class='menu'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaccess']->value, 'label', false, 'LSobject_type');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['LSobject_type']->value => $_smarty_tpl->tpl_vars['label']->value) {
?>
        <li class='menu'><a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSobject_type']->value);?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
</a></li>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSaddonsViewsAccess']->value, 'access');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['access']->value) {
?>
        <?php if ($_smarty_tpl->tpl_vars['access']->value['showInMenu']) {?>
        <li class='menu'><a href='addon_view.php?LSaddon=<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['LSaddon']);?>
&view=<?php echo rawurlencode($_smarty_tpl->tpl_vars['access']->value['id']);?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['access']->value['label']),$_smarty_tpl);?>
</a></li>
        <?php }?>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      </ul>
    </td>
    <td id='status'>
    <span><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang_label']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSlang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
        <option value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['lang']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</option>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['connected_as']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 <span id='user_name'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsession_username']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</span><?php }?>
    <a href='index.php?LSsession_refresh=1'><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
" title="<?php echo LStemplate_smarty_tr(array('msg'=>"Refresh my access rights"),$_smarty_tpl);?>
" /></a>
    <?php if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
' alt='Logout' title='Logout' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>
    
    

    
<?php }
}
